@@ -1,6 +1,7 @@
 use crate::io::storage::Storage;
 use crate::natives_and_messaging::*;
-use crate::widget::Widget;
+use crate::widget::label::Label;
+use crate::widget::radiobutton::RadioButton;
 use crate::window::{Application, Frame, Attributes};
 
 pub struct DemoWindow {
@@ -34,7 +35,15 @@ impl Application for DemoWindow {
     }
 
     fn ui(&self,frame: Frame) {
-        Widget::new(WT_BUTTON, Attributes::new(0, "NXUI Button".to_string(), 350, 250, 100, 100), frame).show();
+        use crate::widget::button::Button;
+        use crate::widget::checkbox::CheckBox;
+        Label::new(Attributes::new(0, "Button Controls".to_string(), 350, 250, 50, 50), frame).show();
+
+        Button::new(Attributes::new(0, "Push Button".to_string(), 350, 250, 100, 100), frame).show();
+        CheckBox::new(Attributes::new(0, "Check Box".to_string(), 150, 250, 500, 100), frame).show();
+        RadioButton::new(Attributes::new(0, "Radio Button".to_string(), 250, 250, 650, 100), frame).show();
+        // Deprecated
+        // Widget::new(WT_BUTTON, Attributes::new(0, "BUTTON".to_string(), 350, 250, 100, 100), frame).show();
         frame.show();
     }
 
