@@ -1,14 +1,22 @@
 //! Provides widgets for building the UI
 
+pub mod button;
+pub mod checkbox;
+pub mod radiobutton;
+pub mod label;
+
 use windows_sys::Win32::Foundation::HINSTANCE;
+use windows_sys::Win32::Graphics::Gdi::BS_DIBPATTERN;
 use windows_sys::Win32::UI::WindowsAndMessaging::*;
 use crate::natives_and_messaging::WidgetStyle;
 use crate::window::{Attributes, Frame};
 
+#[deprecated(since="0.15.2", note="Please use the respective widget structure")]
 pub struct Widget {
     pub handle: windows_sys::Win32::Foundation::HWND
 }
 
+#[deprecated(since="0.15.2", note="Please use the respective widget structure")]
 impl Widget {
     pub fn new(widget_type:WidgetStyle,attributes: Attributes,frame: Frame) -> Self {
         use windows_sys::Win32::UI::WindowsAndMessaging::CreateWindowExA;
